local media = LibStub("LibSharedMedia-3.0")

function PWBInfo:BuildGui()
	-- Information frame setup
	InfoFrame = CreateFrame("Frame", nil, UIParent)
	InfoFrame:SetFrameStrata("BACKGROUND")
	InfoFrame:SetPoint("BOTTOMLEFT", self.db.x, self.db.y)
	InfoFrame:SetBackdrop({bgFile = media:Fetch("background", "Blizzard Tooltip"), tile = false})

	-- Information frame movement
	InfoFrame:RegisterForDrag('LeftButton')
	InfoFrame:SetClampedToScreen(true)
	InfoFrame:SetScript("OnDragStart", function(self) PWBInfo:Dragstart(self) end )
	InfoFrame:SetScript('OnDragStop', function(self) PWBInfo:Dragstop(self) end )

	-- Information text
	VengeanceText = InfoFrame:CreateFontString(nil, 'OVERLAY')
	VengeanceText:SetPoint("LEFT", 4, 0);
	VengeanceText:SetFont(media:Fetch("font", self.db.font), self.db.fontsize, "OUTLINE")
	VengeanceText:SetText(0)

	PWBInfo:UpdateStyling()
	PWBInfo:UpdateVisiblity()
end

function PWBInfo:UpdateStyling()
	local style = nil

	if self.db.useDefaults then
		style = Protwarbar.db.profile.default.appearence
	else
		style = self.db
	end

	local scale = Protwarbar.db.profile.default.appearence.scale

	InfoFrame:SetWidth(self.db.width * scale)
	InfoFrame:SetHeight(self.db.height * scale)
	InfoFrame:SetMovable(not Protwarbar.db.profile.locked)
	InfoFrame:EnableMouse(not Protwarbar.db.profile.locked)
	InfoFrame:SetPoint("BOTTOMLEFT", self.db.x, self.db.y)
	VengeanceText:SetFont(media:Fetch("font", style.font), style.fontsize, "OUTLINE")

	if Protwarbar.db.profile.locked then
		InfoFrame:SetBackdropColor(style.background[1], style.background[2],style.background[3], style.background[4])
	else
		InfoFrame:SetBackdropColor(Protwarbar.db.profile.default.appearence.unlockbg[1],
			Protwarbar.db.profile.default.appearence.unlockbg[2],
			Protwarbar.db.profile.default.appearence.unlockbg[3],
			Protwarbar.db.profile.default.appearence.unlockbg[4])
	end

end

function PWBInfo:UpdateVisiblity()
	if self.db.enabled == true and Protwarbar:IsVisible() then
		InfoFrame:Show()
	else
		InfoFrame:Hide()
	end
end

function PWBInfo:Dragstart(frame)
	if not Protwarbar.db.profile.locked then
		frame:StartMoving()
	end
end

function PWBInfo:Dragstop(frame)
	frame:StopMovingOrSizing()

	self.db.x = InfoFrame:GetLeft()
	self.db.y = InfoFrame:GetBottom()
end