local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")
local media = LibStub("LibSharedMedia-3.0")

function PWBRagebar:CreateOptions()

	local textures = media:List("statusbar")
	local fonts = media:List("font")
	local backgrounds = media:List("background")

	local options = {
		type = "group",
		name = "Ragebar",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  	order = 1,
					  	name = L["Enable"],
					  	desc = L["Enable"],
					  	type = "toggle",
					  	set = function(info,val) self.db.enabled = val Protwarbar:RefreshConfig() end,
					  	get = function(info) return self.db.enabled end
					},
				},
			},
			group3 = {
				name = L["Position"],
				type = "group",
				order = 3,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 1,
					},
					x = {
						order = 3,
						name = "X",
						desc = "X",
						type = "range",
						min = 1,
						max = 2560,
						step = 1,
						set = function(info,val) self.db.x = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.x end
					},
					y = {
						order = 3,
						name = "Y",
						desc = "Y",
						type = "range",
						min = 1,
						max = 2048,
						step = 1,
						set = function(info,val) self.db.y = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.y end
					},
					desc_6 = {
						type = 'description',
						name = " ",
						order = 6,
					},
					width = {
						order = 7,
						name = L["Width"],
						desc = L["Width of bar"],
						type = "range",
						min = 5,
						max = 750,
						step = 1,
						set = function(info,val) self.db.width = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.width end
					},
					height = {
						order = 8,
						name = L["Height"],
						desc = L["Height of bar"],
						type = "range",
						min = 5,
						max = 750,
						step = 1,
						set = function(info,val) self.db.height = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.height end
					},
					desc_9 = {
						type = 'description',
						name = " ",
						order = 9,
					},
				},
			},
			group4 = {
				name = L["Appearance"],
				type = "group",
				order = 4,
				args = {
					enable = {
						order = 1,
						name = L["Use defaults"],
						desc = L["Use defaults"],
						type = "toggle",
						set = function(info,val) self.db.useDefaults = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.useDefaults end
					},
					desc_2 = {
						type = 'description',
						name = " ",
						order = 2,
					},
					reverse = {
					  order = 10,
					  name = L["Reverse"],
					  desc = L["Reverse the way the bar fills up"],
					  disabled = function() return self.db.useDefaults == true end,
					  type = "toggle",
					  set = function(info,val) self.db.reverse = val Protwarbar:RefreshConfig() end,
					  get = function(info) return self.db.reverse end
					},
					orient = {
						order = 11,
						name = L["Orientation"],
						desc = L["Orientation"],
						disabled = function() return self.db.useDefaults == true end,
						type = "select",
						values = function()
							orientations = {
								["HORIZONTAL"] = "Horizontal",
								["VERTICAL"] = "Vertical",
							}
							return orientations
						end,
						set = function(info, v)
								self.db.orientation = v
								Protwarbar:RefreshConfig()
							end,
						get = function(info) return self.db.orientation end
					},
					desc_bg_head = {
						type = 'header',
						name = L["Bar background"],
						order = 31,
					},
					barTexture = {
						name = L["Texture"],
						desc = L["Texture for ragebar"],
						disabled = function() return self.db.useDefaults == true end,
						type = "select",
						values = textures,
						order = 34,
						width = "normal",
						set = function(info, v)
								self.db.barTexture = media:List("statusbar")[v]
								Protwarbar:RefreshConfig()
							end,
						get = function(info) return GetLSMIndex("statusbar", self.db.barTexture) end
					},
					bg = {
						name = L["Background color"],
						desc = L["Color of bar Background"],
						disabled = function() return self.db.useDefaults == true end,
						type = "color",
						order = 33,
						width = "normal",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.barBackground[1] = r;
								self.db.barBackground[2] = g;
								self.db.barBackground[3] = b;
								self.db.barBackground[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.barBackground[1], self.db.barBackground[2],
													self.db.barBackground[3], self.db.barBackground[4]
							end
					},

					desc_bg = {
						type = 'header',
						name = L["Bar text"],
						order = 50,
					},
					fontsize = {
						order = 51,
						name = L["Font Size"],
						desc = L["Size of the font used on the ragebar"],
						disabled = function() return self.db.useDefaults == true end,
						type = "range",
						min = 3,
						max = 50,
						step = 1,
						set = function(info,val) self.db.fontsize = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.fontsize end
					},
					barFont = {
						name = L["Font"],
						desc = L["Font for ragebar"],
						disabled = function() return self.db.useDefaults == true end,
						type = "select",
						values = fonts,
						order = 52,
						set = function(info, v)
								self.db.font = media:List("font")[v]
								Protwarbar:RefreshConfig()
							end,
						get = function(info) return GetLSMIndex("font", self.db.font) end
					},
				},
			},
			group2 = {
				name = L["Bar colors"],
				type = "group",
				order = 2,
				args = {
					desc_colour = {
						type = 'header',
						name = L["Bar colors"],
						order = 1,
					},
					level1 = {
						order = 10,
						name = L["Threshold"],
						desc = L["Threshold"],
						type = "range",
						min = 0,
						max = 120,
						step = 1,
						set = function(info,val) self.db.barlevel[1] = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.barlevel[1] end
					},
					color1 = {
						name = L["Threshold color"],
						desc = L["Threshold color"],
						type = "color",
						order = 15,
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.color1[1] = r;
								self.db.color1[2] = g;
								self.db.color1[3] = b;
								self.db.color1[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.color1[1], self.db.color1[2],
													self.db.color1[3], self.db.color1[4]
							end
					},
					desc_color1 = {
						type = 'description',
						name = " ",
						order = 19,
					},
					level2 = {
						order = 20,
						name = L["Threshold"],
						desc = L["Threshold"],
						type = "range",
						min = 0,
						max = 120,
						step = 1,
						set = function(info,val) self.db.barlevel[2] = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.barlevel[2] end
					},
					color2 = {
						name = L["Threshold color"],
						desc = L["Threshold color"],
						type = "color",
						order = 25,
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.color2[1] = r;
								self.db.color2[2] = g;
								self.db.color2[3] = b;
								self.db.color2[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.color2[1], self.db.color2[2],
													self.db.color2[3], self.db.color2[4]
							end
					},
					desc_color2 = {
						type = 'description',
						name = " ",
						order = 29,
					},
					level3 = {
						order = 30,
						name = L["Threshold"],
						desc = L["Threshold"],
						type = "range",
						min = 0,
						max = 120,
						step = 1,
						set = function(info,val) self.db.barlevel[3] = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.barlevel[3] end
					},
					color3 = {
						order = 35,
						name = L["Threshold color"],
						desc = L["Threshold color"],
						type = "color",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.color3[1] = r;
								self.db.color3[2] = g;
								self.db.color3[3] = b;
								self.db.color3[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.color3[1], self.db.color3[2],
													self.db.color3[3], self.db.color3[4]
							end
					},
					desc_color3 = {
						type = 'description',
						name = " ",
						order = 39,
					},
					level4 = {
						order = 40,
						name = L["Threshold"],
						desc = L["Threshold"],
						type = "range",
						min = 0,
						max = 120,
						step = 1,
						set = function(info,val) self.db.barlevel[4] = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.barlevel[4] end
					},
					color4 = {
						order = 45,
						name = L["Threshold color"],
						desc = L["Threshold color"],
						type = "color",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.color4[1] = r;
								self.db.color4[2] = g;
								self.db.color4[3] = b;
								self.db.color4[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.color4[1], self.db.color4[2],
													self.db.color4[3], self.db.color4[4]
							end
					},
					desc_color4 = {
						type = 'description',
						name = " ",
						order = 49,
					},
					level5 = {
						order = 50,
						name = L["Threshold"],
						desc = L["Threshold"],
						type = "range",
						min = 120,
						max = 120,
						step = 1,
						set = function(info,val)  end,
						get = function(info) return 120 end
					},
					color5 = {
						order = 55,
						name = L["Color full bar"],
						desc = L["Color full bar"],
						type = "color",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.color5[1] = r;
								self.db.color5[2] = g;
								self.db.color5[3] = b;
								self.db.color5[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.color5[1], self.db.color5[2],
													self.db.color5[3], self.db.color5[4]
							end
					},
				},
			},
		}
	}

	return options
end

function GetLSMIndex(t, value)
	local media = LibStub("LibSharedMedia-3.0")

	for k, v in pairs(media:List(t)) do
		if v == value then
			return k
		end
	end
	return nil
end